'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global BG, parseUri, optionalSettings:true, log, updateAcceptableAdsUI */

// Check or uncheck each loaded DOM option checkbox according to the
// user's saved settings.
const generalInit = function () {
  // Handle incoming clicks from bandaids.js & '/installed'
  try {
    if (parseUri.parseSearch(window.location.search).aadisabled === 'true') {
      $('#acceptable_ads_info').show();
    }
  } catch (ex) {
    log(ex);
  }

  const subs = BG.getSubscriptionsMinusText();

  const acceptableAdsClicked = function (isEnabled) {
    if (isEnabled) {
      BG.subscribe({ id: 'acceptable_ads' });
      BG.unsubscribe({ id: 'acceptable_ads_privacy' });
      updateAcceptableAdsUI(true, false);
    } else {
      BG.unsubscribe({ id: 'acceptable_ads', del: false });
      BG.unsubscribe({ id: 'acceptable_ads_privacy', del: false });
      updateAcceptableAdsUI(false, false);
    }
  };

  const acceptableAdsPrivacyClicked = function (isEnabled) {
    if (isEnabled) {
      BG.subscribe({ id: 'acceptable_ads_privacy' });
      BG.unsubscribe({ id: 'acceptable_ads', del: false });
      updateAcceptableAdsUI(true, true);
    } else {
      BG.unsubscribe({ id: 'acceptable_ads_privacy', del: false });
      BG.subscribe({ id: 'acceptable_ads' });
      updateAcceptableAdsUI(true, false);
    }
  };

  // if the user is subscribed to AA or AA Privacy when
  // the page load, update the checkboxes respective UI
  if ('acceptable_ads' in subs && subs.acceptable_ads.subscribed) {
    updateAcceptableAdsUI(true, false);
  }

  if ('acceptable_ads_privacy' in subs && subs.acceptable_ads_privacy.subscribed) {
    updateAcceptableAdsUI(true, true);
  }

  for (const name in optionalSettings) {
    $(`#enable_${name}`)
      .attr('checked', optionalSettings[name]);
  }

  $("input[type='checkbox']:not(.disabled)").change(function checkboxChangeFunction() {
    const isEnabled = $(this).is(':checked');
    const name = this.id.substring(7); // TODO: hack
    if (this.id === 'acceptable_ads') {
      acceptableAdsClicked(isEnabled);
      return;
    }
    if (this.id === 'acceptable_ads_privacy') {
      acceptableAdsPrivacyClicked(isEnabled);
      return;
    }

    // if the user enables/disable Local CDN
    // start or end the Local CDN
    if (name === 'local_cdn') {
      if (isEnabled) {
        BG.LocalCDN.start();
      } else {
        BG.LocalCDN.end();
      }
    }

    BG.setSetting(name, isEnabled);
  });

  $('#enable_show_advanced_options').change(function showAdvancedOptionsChange() {
    // Reload the page to show or hide the advanced options on the
    // options page -- after a moment so we have time to save the option.
    // Also, disable all advanced options, so that non-advanced users will
    // not end up with debug/beta/test options enabled.
    if (!this.checked) {
      $('.advanced input[type="checkbox"]:checked').each(function advancedCheckboxCheckedEach() {
        BG.setSetting(this.id.substr(7), false);
      });
    }

    window.setTimeout(() => {
      window.location.reload();
    }, 50);
  });
};
